<?php

namespace QUI\Controls\ChildrenList;

use QUI;
use QUI\Projects\Media\Image;

/**
 * Class ChildrenListItem
 *
 * Represents a single item of a ChildrenList.
 *
 * This is a generic, Site-independent class.
 */
class ChildrenListItem extends QUI\QDOM
{
    /**
     * @param array $attributes (optional)
     */
    public function __construct(array $attributes = [])
    {
        // Default attributes
        $this->setAttributes([
            'title'       => false,     // string
            'description' => false,     // string
            'date'        => false,     // \DateTime or date string
            'image'       => false,     // \QUI\Projects\Media\Image or QUIQQER image URL
            'author'      => false,     // string
            'url'         => false      // url
        ]);

        // Set custom attributes
        $this->setAttributes($attributes);
    }

    /**
     * @return string
     */
    public function getTitle(): string
    {
        return $this->getStringAttribute('title');
    }

    /**
     * @return string
     */
    public function getDescription(): string
    {
        return $this->getStringAttribute('description');
    }

    /**
     * Get *formatted* date.
     *
     * @param QUI\Locale|null $Locale (optional) - Locale the date is formatted by
     * @return string
     */
    public function getDate(?QUI\Locale $Locale = null): string
    {
        $date = $this->getAttribute('date');

        if (!($date instanceof \DateTime)) {
            $date = \date_create($date);
        }

        if (!$date) {
            return '';
        }

        if (empty($Locale)) {
            $Locale = QUI::getLocale();
        }

        return $Locale->formatDate($date->getTimestamp());
    }

    /**
     * @return string
     */
    public function getImage(): string
    {
        $image = $this->getAttribute('image');

        if ($image instanceof Image) {
            return $image->getUrl();
        }

        return $this->getStringAttribute('image');
    }

    /**
     * @return string
     */
    public function getAuthor(): string
    {
        return $this->getStringAttribute('author');
    }

    /**
     * @return string
     */
    public function getUrl(): string
    {
        return $this->getStringAttribute('url');
    }

    /**
     * Get a generic string attribute from class.
     *
     * @param string $key
     * @return string
     */
    protected function getStringAttribute(string $key): string
    {
        $value = $this->getAttribute($key);

        if (empty($value) || !\is_string($value)) {
            return '';
        }

        return \trim($value);
    }
}
